@@ -80,7 +80,14 @@ class Repo:
     from dvc.repo.status import status
     from dvc.repo.update import update
 
-    def __init__(self, root_dir=None, scm=None, rev=None, subrepos=False):
+    def __init__(
+        self,
+        root_dir=None,
+        scm=None,
+        rev=None,
+        subrepos=False,
+        uninitialized=False,
+    ):
         from dvc.cache import Cache
         from dvc.data_cloud import DataCloud
         from dvc.lock import make_lock
@@ -103,7 +110,12 @@ class Repo:
             )
             self.state = StateNoop()
         else:
-            root_dir = self.find_root(root_dir)
+            try:
+                root_dir = self.find_root(root_dir)
+            except NotDvcRepoError:
+                if not uninitialized:
+                    raise
+                root_dir = SCM(root_dir or os.curdir).root_dir
             self.root_dir = os.path.abspath(os.path.realpath(root_dir))
             self.tree = LocalTree(
                 self,
@@ -120,8 +132,7 @@ class Repo:
             self.scm = SCM(self.root_dir, no_scm=no_scm)
 
         self.tmp_dir = os.path.join(self.dvc_dir, "tmp")
-        self.index_dir = os.path.join(self.tmp_dir, "index")
-        makedirs(self.index_dir, exist_ok=True)
+        makedirs(self.tmp_dir, exist_ok=True)
 
         hardlink_lock = self.config["core"].get("hardlink_lock", False)
         self.lock = make_lock(
@@ -542,12 +553,6 @@ class Repo:
         """
         return self._collect_stages()
 
-    @cached_property
-    def plot_templates(self):
-        from .plots.template import PlotTemplates
-
-        return PlotTemplates(self.dvc_dir)
-
     def _collect_stages(self):
         stages = []
         outs = set()
